@@ -63,12 +63,12 @@ void MuonMainWindow::initObject()
     m_backend = new QApt::Backend;
     connect(m_backend, SIGNAL(workerEvent(QApt::WorkerEvent)),
             this, SLOT(workerEvent(QApt::WorkerEvent)));
-    connect(m_backend, SIGNAL(errorOccurred(QApt::ErrorCode, QVariantMap)),
-            this, SLOT(errorOccurred(QApt::ErrorCode, QVariantMap)));
-    connect(m_backend, SIGNAL(warningOccurred(QApt::WarningCode, QVariantMap)),
-            this, SLOT(warningOccurred(QApt::WarningCode, QVariantMap)));
-    connect(m_backend, SIGNAL(questionOccurred(QApt::WorkerQuestion, QVariantMap)),
-            this, SLOT(questionOccurred(QApt::WorkerQuestion, QVariantMap)));
+    connect(m_backend, SIGNAL(errorOccurred(QApt::ErrorCode,QVariantMap)),
+            this, SLOT(errorOccurred(QApt::ErrorCode,QVariantMap)));
+    connect(m_backend, SIGNAL(warningOccurred(QApt::WarningCode,QVariantMap)),
+            this, SLOT(warningOccurred(QApt::WarningCode,QVariantMap)));
+    connect(m_backend, SIGNAL(questionOccurred(QApt::WorkerQuestion,QVariantMap)),
+            this, SLOT(questionOccurred(QApt::WorkerQuestion,QVariantMap)));
     connect(m_backend, SIGNAL(packageChanged()), this, SLOT(setActionsEnabled()));
     m_backend->init();
     m_originalState = m_backend->currentCacheState();
@@ -256,8 +256,9 @@ void MuonMainWindow::errorOccurred(QApt::ErrorCode code, const QVariantMap &args
     }
     case QApt::FetchError:
         text = i18nc("@label",
-                     "Could not download packages");
-        title = i18nc("@title:window", "Download failed");
+                     "Changes could not be applied since some packages "
+                     "could not be downloaded.");
+        title = i18nc("@title:window", "Failed to Apply Changes");
         KMessageBox::error(this, text, title);
         break;
     case QApt::CommitError: {
@@ -628,7 +629,7 @@ void MuonMainWindow::runSourcesEditor(bool update)
     proc->setProgram(arguments);
     find(winID)->setEnabled(false);
     proc->start();
-    connect(proc, SIGNAL(finished(int, QProcess::ExitStatus)),
+    connect(proc, SIGNAL(finished(int,QProcess::ExitStatus)),
             this, SLOT(sourcesEditorFinished(int)));
 }
 
@@ -658,12 +659,11 @@ void MuonMainWindow::easterEggTriggered()
     dialog->setMainWidget(widget);
     dialog->show();
 
-    QString mooFile = KStandardDirs::installPath("data") % QLatin1Literal("libmuon/moo.ogg");
+    QString mooFile = KStandardDirs::locate("data", "libmuon/moo.ogg");
     Phonon::MediaObject *music =
         Phonon::createPlayer(Phonon::MusicCategory,
                              Phonon::MediaSource(mooFile));
     music->play();
-    delete music;
 }
 
 #include "MuonMainWindow.moc"
