@@ -32,6 +32,7 @@
 // KDE includes
 #include <KIcon>
 #include <KLocale>
+#include <KMessageBox>
 #include <KPixmapSequence>
 #include <KPixmapSequenceOverlayPainter>
 #include <KDebug>
@@ -66,6 +67,8 @@ UpdaterWidget::UpdaterWidget(QWidget *parent) :
     m_updateView = new QTreeView(page1);
     m_updateView->setAlternatingRowColors(true);
     m_updateView->header()->setResizeMode(0, QHeaderView::Stretch);
+    m_updateView->header()->setResizeMode(1, QHeaderView::ResizeToContents);
+    m_updateView->header()->setStretchLastSection(false);
     m_updateView->setModel(m_updateModel);
     connect(m_updateView->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
             this, SLOT(selectionChanged(QItemSelection,QItemSelection)));
@@ -161,7 +164,7 @@ void UpdaterWidget::populateUpdateModel()
 
         // Set update type
         bool securityFound = false;
-        foreach (QString archive, package->archives()) {
+        for (const QString &archive : package->archives()) {
             if (archive.contains(QLatin1String("security"))) {
                 securityFound = true;
                 break;
@@ -186,7 +189,7 @@ void UpdaterWidget::populateUpdateModel()
 
         // Set update type
         bool securityFound = false;
-        foreach (QString archive, package->archives()) {
+        for (const QString &archive : package->archives()) {
             if (archive.contains(QLatin1String("security"))) {
                 securityFound = true;
                 break;
@@ -227,6 +230,7 @@ void UpdaterWidget::populateUpdateModel()
     QApplication::restoreOverrideCursor();
     m_backend->markPackagesForUpgrade();
 
+    checkAllMarked();
     checkUpToDate();
 }
 
@@ -256,13 +260,13 @@ void UpdaterWidget::checkApps(QList<Application *> apps, bool checked)
     QApplication::restoreOverrideCursor();
 }
 
-void UpdaterWidget::checkChanges(const QHash<QApt::Package::State, QApt::PackageList> &removals)
+void UpdaterWidget::checkChanges(const QHash<QApt::Package::State, QApt::PackageList> &changes)
 {
-    if (removals.isEmpty()) {
+    if (changes.isEmpty()) {
         return;
     }
 
-    ChangesDialog *dialog = new ChangesDialog(this, removals);
+    ChangesDialog *dialog = new ChangesDialog(this, changes);
     int res = dialog->exec();
 
     if (res != QDialog::Accepted)
@@ -288,6 +292,37 @@ void UpdaterWidget::selectionChanged(const QItemSelection &selected,
     emit packageChanged(package);
 }
 
+void UpdaterWidget::checkAllMarked()
+{
+    QApt::PackageList upgradeable = m_backend->upgradeablePackages();
+    int markedCount = m_backend->packageCount(QApt::Package::ToUpgrade);
+
+    if (markedCount < upgradeable.count())
+    {
+        QString text = i18nc("@label", "Not all packages could be marked for upgrade. "
+                             "The available upgrades may require new packages to "
+                             "be installed or removed. Do you want to mark upgrades "
+                             "that may require the installation or removal of additional "
+                             "packages?");
+        QString title = i18nc("@title:window", "Unable to Mark Upgrades");
+        KGuiItem markUpgrades(i18nc("@action", "Mark Upgrades"));
+
+        int res = KMessageBox::questionYesNo(this, text, title, markUpgrades);
+
+        if (res != KMessageBox::Yes)
+            return;
+
+        // Mark dist upgrade
+        m_oldCacheState = m_backend->currentCacheState();
+        m_backend->saveCacheState();
+        m_backend->markPackagesForDistUpgrade();
+
+        // Show user packages to be installed/removed
+        auto changes = m_backend->stateChanges(m_oldCacheState, upgradeable);
+        checkChanges(changes);
+    }
+}
+
 void UpdaterWidget::checkUpToDate()
 {
     if(m_backend->upgradeablePackages().isEmpty()) {
